@@ -129,8 +129,10 @@ def gensolution(script_path, config, inports, outports, override_readme = False,
                 if re.match('except NameError:',line) :
                     line = read_fn.readline()
                     continue
-                if exclude_section and re.match('[\w#]+',line)  :
-                    exclude_section = False
+
+                if exclude_section and not re.match('[\w#]+',line) :
+                    line = read_fn.readline()
+                    continue
 
                 # activate call function
                 line = re.sub(r'^#\s*api.set_port_callback', 'api.set_port_callback', line)
