@@ -1,6 +1,5 @@
 import sdi_utils.gensolution as gs
-import sdi_utils.set_logging as slog
-import sdi_utils.textfield_parser as tfp
+import deprecated.set_logging as slog
 import sdi_utils.tprogress as tp
 
 
